# flake8: noqa
"""
Copyright 2020 - Present Okta, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

# AUTO-GENERATED! DO NOT EDIT FILE DIRECTLY
# SEE CONTRIBUTOR DOCUMENTATION

import okta.models.activate_factor_request as activate_factor_request
ActivateFactorRequest = activate_factor_request.ActivateFactorRequest
import okta.models.app_and_instance_condition_evaluator_app_or_instance as app_and_instance_condition_evaluator_app_or_instance
AppAndInstanceConditionEvaluatorAppOrInstance = app_and_instance_condition_evaluator_app_or_instance.AppAndInstanceConditionEvaluatorAppOrInstance
import okta.models.app_and_instance_policy_rule_condition as app_and_instance_policy_rule_condition
AppAndInstancePolicyRuleCondition = app_and_instance_policy_rule_condition.AppAndInstancePolicyRuleCondition
import okta.models.app_instance_policy_rule_condition as app_instance_policy_rule_condition
AppInstancePolicyRuleCondition = app_instance_policy_rule_condition.AppInstancePolicyRuleCondition
import okta.models.app_link as app_link
AppLink = app_link.AppLink
import okta.models.app_user as app_user
AppUser = app_user.AppUser
import okta.models.app_user_credentials as app_user_credentials
AppUserCredentials = app_user_credentials.AppUserCredentials
import okta.models.app_user_password_credential as app_user_password_credential
AppUserPasswordCredential = app_user_password_credential.AppUserPasswordCredential
import okta.models.application as application
Application = application.Application
import okta.models.application_accessibility as application_accessibility
ApplicationAccessibility = application_accessibility.ApplicationAccessibility
import okta.models.application_credentials as application_credentials
ApplicationCredentials = application_credentials.ApplicationCredentials
import okta.models.application_credentials_o_auth_client as application_credentials_o_auth_client
ApplicationCredentialsOAuthClient = application_credentials_o_auth_client.ApplicationCredentialsOAuthClient
import okta.models.application_credentials_scheme as application_credentials_scheme
ApplicationCredentialsScheme = application_credentials_scheme.ApplicationCredentialsScheme
import okta.models.application_credentials_signing as application_credentials_signing
ApplicationCredentialsSigning = application_credentials_signing.ApplicationCredentialsSigning
import okta.models.application_credentials_signing_use as application_credentials_signing_use
ApplicationCredentialsSigningUse = application_credentials_signing_use.ApplicationCredentialsSigningUse
import okta.models.application_credentials_username_template as application_credentials_username_template
ApplicationCredentialsUsernameTemplate = application_credentials_username_template.ApplicationCredentialsUsernameTemplate
import okta.models.application_group_assignment as application_group_assignment
ApplicationGroupAssignment = application_group_assignment.ApplicationGroupAssignment
import okta.models.application_licensing as application_licensing
ApplicationLicensing = application_licensing.ApplicationLicensing
import okta.models.application_settings as application_settings
ApplicationSettings = application_settings.ApplicationSettings
import okta.models.application_settings_application as application_settings_application
ApplicationSettingsApplication = application_settings_application.ApplicationSettingsApplication
import okta.models.application_settings_notifications as application_settings_notifications
ApplicationSettingsNotifications = application_settings_notifications.ApplicationSettingsNotifications
import okta.models.application_settings_notifications_vpn as application_settings_notifications_vpn
ApplicationSettingsNotificationsVpn = application_settings_notifications_vpn.ApplicationSettingsNotificationsVpn
import okta.models.application_settings_notifications_vpn_network as application_settings_notifications_vpn_network
ApplicationSettingsNotificationsVpnNetwork = application_settings_notifications_vpn_network.ApplicationSettingsNotificationsVpnNetwork
import okta.models.application_sign_on_mode as application_sign_on_mode
ApplicationSignOnMode = application_sign_on_mode.ApplicationSignOnMode
import okta.models.application_visibility as application_visibility
ApplicationVisibility = application_visibility.ApplicationVisibility
import okta.models.application_visibility_hide as application_visibility_hide
ApplicationVisibilityHide = application_visibility_hide.ApplicationVisibilityHide
import okta.models.assign_role_request as assign_role_request
AssignRoleRequest = assign_role_request.AssignRoleRequest
import okta.models.authentication_provider as authentication_provider
AuthenticationProvider = authentication_provider.AuthenticationProvider
import okta.models.authentication_provider_type as authentication_provider_type
AuthenticationProviderType = authentication_provider_type.AuthenticationProviderType
import okta.models.authorization_server as authorization_server
AuthorizationServer = authorization_server.AuthorizationServer
import okta.models.authorization_server_credentials as authorization_server_credentials
AuthorizationServerCredentials = authorization_server_credentials.AuthorizationServerCredentials
import okta.models.authorization_server_credentials_rotation_mode as authorization_server_credentials_rotation_mode
AuthorizationServerCredentialsRotationMode = authorization_server_credentials_rotation_mode.AuthorizationServerCredentialsRotationMode
import okta.models.authorization_server_credentials_signing_config as authorization_server_credentials_signing_config
AuthorizationServerCredentialsSigningConfig = authorization_server_credentials_signing_config.AuthorizationServerCredentialsSigningConfig
import okta.models.authorization_server_credentials_use as authorization_server_credentials_use
AuthorizationServerCredentialsUse = authorization_server_credentials_use.AuthorizationServerCredentialsUse
import okta.models.auto_login_application as auto_login_application
AutoLoginApplication = auto_login_application.AutoLoginApplication
import okta.models.auto_login_application_settings as auto_login_application_settings
AutoLoginApplicationSettings = auto_login_application_settings.AutoLoginApplicationSettings
import okta.models.auto_login_application_settings_sign_on as auto_login_application_settings_sign_on
AutoLoginApplicationSettingsSignOn = auto_login_application_settings_sign_on.AutoLoginApplicationSettingsSignOn
import okta.models.basic_application_settings as basic_application_settings
BasicApplicationSettings = basic_application_settings.BasicApplicationSettings
import okta.models.basic_application_settings_application as basic_application_settings_application
BasicApplicationSettingsApplication = basic_application_settings_application.BasicApplicationSettingsApplication
import okta.models.basic_auth_application as basic_auth_application
BasicAuthApplication = basic_auth_application.BasicAuthApplication
import okta.models.before_scheduled_action_policy_rule_condition as before_scheduled_action_policy_rule_condition
BeforeScheduledActionPolicyRuleCondition = before_scheduled_action_policy_rule_condition.BeforeScheduledActionPolicyRuleCondition
import okta.models.bookmark_application as bookmark_application
BookmarkApplication = bookmark_application.BookmarkApplication
import okta.models.bookmark_application_settings as bookmark_application_settings
BookmarkApplicationSettings = bookmark_application_settings.BookmarkApplicationSettings
import okta.models.bookmark_application_settings_application as bookmark_application_settings_application
BookmarkApplicationSettingsApplication = bookmark_application_settings_application.BookmarkApplicationSettingsApplication
import okta.models.browser_plugin_application as browser_plugin_application
BrowserPluginApplication = browser_plugin_application.BrowserPluginApplication
import okta.models.call_user_factor as call_user_factor
CallUserFactor = call_user_factor.CallUserFactor
import okta.models.call_user_factor_profile as call_user_factor_profile
CallUserFactorProfile = call_user_factor_profile.CallUserFactorProfile
import okta.models.catalog_application as catalog_application
CatalogApplication = catalog_application.CatalogApplication
import okta.models.catalog_application_status as catalog_application_status
CatalogApplicationStatus = catalog_application_status.CatalogApplicationStatus
import okta.models.change_password_request as change_password_request
ChangePasswordRequest = change_password_request.ChangePasswordRequest
import okta.models.client_policy_condition as client_policy_condition
ClientPolicyCondition = client_policy_condition.ClientPolicyCondition
import okta.models.context_policy_rule_condition as context_policy_rule_condition
ContextPolicyRuleCondition = context_policy_rule_condition.ContextPolicyRuleCondition
import okta.models.create_session_request as create_session_request
CreateSessionRequest = create_session_request.CreateSessionRequest
import okta.models.create_user_request as create_user_request
CreateUserRequest = create_user_request.CreateUserRequest
import okta.models.csr as csr
Csr = csr.Csr
import okta.models.csr_metadata as csr_metadata
CsrMetadata = csr_metadata.CsrMetadata
import okta.models.csr_metadata_subject as csr_metadata_subject
CsrMetadataSubject = csr_metadata_subject.CsrMetadataSubject
import okta.models.csr_metadata_subject_alt_names as csr_metadata_subject_alt_names
CsrMetadataSubjectAltNames = csr_metadata_subject_alt_names.CsrMetadataSubjectAltNames
import okta.models.device_policy_rule_condition as device_policy_rule_condition
DevicePolicyRuleCondition = device_policy_rule_condition.DevicePolicyRuleCondition
import okta.models.device_policy_rule_condition_platform as device_policy_rule_condition_platform
DevicePolicyRuleConditionPlatform = device_policy_rule_condition_platform.DevicePolicyRuleConditionPlatform
import okta.models.duration as duration
Duration = duration.Duration
import okta.models.email_user_factor as email_user_factor
EmailUserFactor = email_user_factor.EmailUserFactor
import okta.models.email_user_factor_profile as email_user_factor_profile
EmailUserFactorProfile = email_user_factor_profile.EmailUserFactorProfile
import okta.models.enabled_status as enabled_status
EnabledStatus = enabled_status.EnabledStatus
import okta.models.event_hook as event_hook
EventHook = event_hook.EventHook
import okta.models.event_hook_channel as event_hook_channel
EventHookChannel = event_hook_channel.EventHookChannel
import okta.models.event_hook_channel_config as event_hook_channel_config
EventHookChannelConfig = event_hook_channel_config.EventHookChannelConfig
import okta.models.event_hook_channel_config_auth_scheme as event_hook_channel_config_auth_scheme
EventHookChannelConfigAuthScheme = event_hook_channel_config_auth_scheme.EventHookChannelConfigAuthScheme
import okta.models.event_hook_channel_config_auth_scheme_type as event_hook_channel_config_auth_scheme_type
EventHookChannelConfigAuthSchemeType = event_hook_channel_config_auth_scheme_type.EventHookChannelConfigAuthSchemeType
import okta.models.event_hook_channel_config_header as event_hook_channel_config_header
EventHookChannelConfigHeader = event_hook_channel_config_header.EventHookChannelConfigHeader
import okta.models.event_subscriptions as event_subscriptions
EventSubscriptions = event_subscriptions.EventSubscriptions
import okta.models.factor_provider as factor_provider
FactorProvider = factor_provider.FactorProvider
import okta.models.factor_result_type as factor_result_type
FactorResultType = factor_result_type.FactorResultType
import okta.models.factor_status as factor_status
FactorStatus = factor_status.FactorStatus
import okta.models.factor_type as factor_type
FactorType = factor_type.FactorType
import okta.models.feature as feature
Feature = feature.Feature
import okta.models.feature_stage as feature_stage
FeatureStage = feature_stage.FeatureStage
import okta.models.feature_stage_state as feature_stage_state
FeatureStageState = feature_stage_state.FeatureStageState
import okta.models.feature_stage_value as feature_stage_value
FeatureStageValue = feature_stage_value.FeatureStageValue
import okta.models.feature_type as feature_type
FeatureType = feature_type.FeatureType
import okta.models.forgot_password_response as forgot_password_response
ForgotPasswordResponse = forgot_password_response.ForgotPasswordResponse
import okta.models.grant_type_policy_rule_condition as grant_type_policy_rule_condition
GrantTypePolicyRuleCondition = grant_type_policy_rule_condition.GrantTypePolicyRuleCondition
import okta.models.group as group
Group = group.Group
import okta.models.group_condition as group_condition
GroupCondition = group_condition.GroupCondition
import okta.models.group_policy_rule_condition as group_policy_rule_condition
GroupPolicyRuleCondition = group_policy_rule_condition.GroupPolicyRuleCondition
import okta.models.group_profile as group_profile
GroupProfile = group_profile.GroupProfile
import okta.models.group_rule as group_rule
GroupRule = group_rule.GroupRule
import okta.models.group_rule_action as group_rule_action
GroupRuleAction = group_rule_action.GroupRuleAction
import okta.models.group_rule_conditions as group_rule_conditions
GroupRuleConditions = group_rule_conditions.GroupRuleConditions
import okta.models.group_rule_expression as group_rule_expression
GroupRuleExpression = group_rule_expression.GroupRuleExpression
import okta.models.group_rule_group_assignment as group_rule_group_assignment
GroupRuleGroupAssignment = group_rule_group_assignment.GroupRuleGroupAssignment
import okta.models.group_rule_group_condition as group_rule_group_condition
GroupRuleGroupCondition = group_rule_group_condition.GroupRuleGroupCondition
import okta.models.group_rule_people_condition as group_rule_people_condition
GroupRulePeopleCondition = group_rule_people_condition.GroupRulePeopleCondition
import okta.models.group_rule_status as group_rule_status
GroupRuleStatus = group_rule_status.GroupRuleStatus
import okta.models.group_rule_user_condition as group_rule_user_condition
GroupRuleUserCondition = group_rule_user_condition.GroupRuleUserCondition
import okta.models.group_type as group_type
GroupType = group_type.GroupType
import okta.models.hardware_user_factor as hardware_user_factor
HardwareUserFactor = hardware_user_factor.HardwareUserFactor
import okta.models.hardware_user_factor_profile as hardware_user_factor_profile
HardwareUserFactorProfile = hardware_user_factor_profile.HardwareUserFactorProfile
import okta.models.identity_provider as identity_provider
IdentityProvider = identity_provider.IdentityProvider
import okta.models.identity_provider_application_user as identity_provider_application_user
IdentityProviderApplicationUser = identity_provider_application_user.IdentityProviderApplicationUser
import okta.models.identity_provider_credentials as identity_provider_credentials
IdentityProviderCredentials = identity_provider_credentials.IdentityProviderCredentials
import okta.models.identity_provider_credentials_client as identity_provider_credentials_client
IdentityProviderCredentialsClient = identity_provider_credentials_client.IdentityProviderCredentialsClient
import okta.models.identity_provider_credentials_signing as identity_provider_credentials_signing
IdentityProviderCredentialsSigning = identity_provider_credentials_signing.IdentityProviderCredentialsSigning
import okta.models.identity_provider_credentials_trust as identity_provider_credentials_trust
IdentityProviderCredentialsTrust = identity_provider_credentials_trust.IdentityProviderCredentialsTrust
import okta.models.identity_provider_policy as identity_provider_policy
IdentityProviderPolicy = identity_provider_policy.IdentityProviderPolicy
import okta.models.identity_provider_policy_rule_condition as identity_provider_policy_rule_condition
IdentityProviderPolicyRuleCondition = identity_provider_policy_rule_condition.IdentityProviderPolicyRuleCondition
import okta.models.inactivity_policy_rule_condition as inactivity_policy_rule_condition
InactivityPolicyRuleCondition = inactivity_policy_rule_condition.InactivityPolicyRuleCondition
import okta.models.inline_hook as inline_hook
InlineHook = inline_hook.InlineHook
import okta.models.inline_hook_channel as inline_hook_channel
InlineHookChannel = inline_hook_channel.InlineHookChannel
import okta.models.inline_hook_channel_config as inline_hook_channel_config
InlineHookChannelConfig = inline_hook_channel_config.InlineHookChannelConfig
import okta.models.inline_hook_channel_config_auth_scheme as inline_hook_channel_config_auth_scheme
InlineHookChannelConfigAuthScheme = inline_hook_channel_config_auth_scheme.InlineHookChannelConfigAuthScheme
import okta.models.inline_hook_channel_config_headers as inline_hook_channel_config_headers
InlineHookChannelConfigHeaders = inline_hook_channel_config_headers.InlineHookChannelConfigHeaders
import okta.models.inline_hook_payload as inline_hook_payload
InlineHookPayload = inline_hook_payload.InlineHookPayload
import okta.models.inline_hook_response as inline_hook_response
InlineHookResponse = inline_hook_response.InlineHookResponse
import okta.models.inline_hook_response_command_value as inline_hook_response_command_value
InlineHookResponseCommandValue = inline_hook_response_command_value.InlineHookResponseCommandValue
import okta.models.inline_hook_response_commands as inline_hook_response_commands
InlineHookResponseCommands = inline_hook_response_commands.InlineHookResponseCommands
import okta.models.inline_hook_status as inline_hook_status
InlineHookStatus = inline_hook_status.InlineHookStatus
import okta.models.inline_hook_type as inline_hook_type
InlineHookType = inline_hook_type.InlineHookType
import okta.models.ion_field as ion_field
IonField = ion_field.IonField
import okta.models.ion_form as ion_form
IonForm = ion_form.IonForm
import okta.models.json_web_key as json_web_key
JsonWebKey = json_web_key.JsonWebKey
import okta.models.jwk_use as jwk_use
JwkUse = jwk_use.JwkUse
import okta.models.lifecycle_expiration_policy_rule_condition as lifecycle_expiration_policy_rule_condition
LifecycleExpirationPolicyRuleCondition = lifecycle_expiration_policy_rule_condition.LifecycleExpirationPolicyRuleCondition
import okta.models.linked_object as linked_object
LinkedObject = linked_object.LinkedObject
import okta.models.linked_object_details as linked_object_details
LinkedObjectDetails = linked_object_details.LinkedObjectDetails
import okta.models.linked_object_details_type as linked_object_details_type
LinkedObjectDetailsType = linked_object_details_type.LinkedObjectDetailsType
import okta.models.log_actor as log_actor
LogActor = log_actor.LogActor
import okta.models.log_authentication_context as log_authentication_context
LogAuthenticationContext = log_authentication_context.LogAuthenticationContext
import okta.models.log_authentication_provider as log_authentication_provider
LogAuthenticationProvider = log_authentication_provider.LogAuthenticationProvider
import okta.models.log_client as log_client
LogClient = log_client.LogClient
import okta.models.log_credential_provider as log_credential_provider
LogCredentialProvider = log_credential_provider.LogCredentialProvider
import okta.models.log_credential_type as log_credential_type
LogCredentialType = log_credential_type.LogCredentialType
import okta.models.log_debug_context as log_debug_context
LogDebugContext = log_debug_context.LogDebugContext
import okta.models.log_event as log_event
LogEvent = log_event.LogEvent
import okta.models.log_geographical_context as log_geographical_context
LogGeographicalContext = log_geographical_context.LogGeographicalContext
import okta.models.log_geolocation as log_geolocation
LogGeolocation = log_geolocation.LogGeolocation
import okta.models.log_ip_address as log_ip_address
LogIpAddress = log_ip_address.LogIpAddress
import okta.models.log_issuer as log_issuer
LogIssuer = log_issuer.LogIssuer
import okta.models.log_outcome as log_outcome
LogOutcome = log_outcome.LogOutcome
import okta.models.log_request as log_request
LogRequest = log_request.LogRequest
import okta.models.log_security_context as log_security_context
LogSecurityContext = log_security_context.LogSecurityContext
import okta.models.log_severity as log_severity
LogSeverity = log_severity.LogSeverity
import okta.models.log_target as log_target
LogTarget = log_target.LogTarget
import okta.models.log_transaction as log_transaction
LogTransaction = log_transaction.LogTransaction
import okta.models.log_user_agent as log_user_agent
LogUserAgent = log_user_agent.LogUserAgent
import okta.models.mdm_enrollment_policy_rule_condition as mdm_enrollment_policy_rule_condition
MdmEnrollmentPolicyRuleCondition = mdm_enrollment_policy_rule_condition.MdmEnrollmentPolicyRuleCondition
import okta.models.o_auth_2_actor as o_auth_2_actor
OAuth2Actor = o_auth_2_actor.OAuth2Actor
import okta.models.o_auth_2_claim as o_auth_2_claim
OAuth2Claim = o_auth_2_claim.OAuth2Claim
import okta.models.o_auth_2_claim_conditions as o_auth_2_claim_conditions
OAuth2ClaimConditions = o_auth_2_claim_conditions.OAuth2ClaimConditions
import okta.models.o_auth_2_client as o_auth_2_client
OAuth2Client = o_auth_2_client.OAuth2Client
import okta.models.o_auth_2_refresh_token as o_auth_2_refresh_token
OAuth2RefreshToken = o_auth_2_refresh_token.OAuth2RefreshToken
import okta.models.o_auth_2_scope as o_auth_2_scope
OAuth2Scope = o_auth_2_scope.OAuth2Scope
import okta.models.o_auth_2_scope_consent_grant as o_auth_2_scope_consent_grant
OAuth2ScopeConsentGrant = o_auth_2_scope_consent_grant.OAuth2ScopeConsentGrant
import okta.models.o_auth_2_scope_consent_grant_source as o_auth_2_scope_consent_grant_source
OAuth2ScopeConsentGrantSource = o_auth_2_scope_consent_grant_source.OAuth2ScopeConsentGrantSource
import okta.models.o_auth_2_scope_consent_grant_status as o_auth_2_scope_consent_grant_status
OAuth2ScopeConsentGrantStatus = o_auth_2_scope_consent_grant_status.OAuth2ScopeConsentGrantStatus
import okta.models.o_auth_2_scopes_mediation_policy_rule_condition as o_auth_2_scopes_mediation_policy_rule_condition
OAuth2ScopesMediationPolicyRuleCondition = o_auth_2_scopes_mediation_policy_rule_condition.OAuth2ScopesMediationPolicyRuleCondition
import okta.models.o_auth_2_token as o_auth_2_token
OAuth2Token = o_auth_2_token.OAuth2Token
import okta.models.o_auth_application_credentials as o_auth_application_credentials
OAuthApplicationCredentials = o_auth_application_credentials.OAuthApplicationCredentials
import okta.models.o_auth_authorization_policy as o_auth_authorization_policy
OAuthAuthorizationPolicy = o_auth_authorization_policy.OAuthAuthorizationPolicy
import okta.models.o_auth_endpoint_authentication_method as o_auth_endpoint_authentication_method
OAuthEndpointAuthenticationMethod = o_auth_endpoint_authentication_method.OAuthEndpointAuthenticationMethod
import okta.models.o_auth_grant_type as o_auth_grant_type
OAuthGrantType = o_auth_grant_type.OAuthGrantType
import okta.models.o_auth_response_type as o_auth_response_type
OAuthResponseType = o_auth_response_type.OAuthResponseType
import okta.models.okta_sign_on_policy as okta_sign_on_policy
OktaSignOnPolicy = okta_sign_on_policy.OktaSignOnPolicy
import okta.models.okta_sign_on_policy_conditions as okta_sign_on_policy_conditions
OktaSignOnPolicyConditions = okta_sign_on_policy_conditions.OktaSignOnPolicyConditions
import okta.models.okta_sign_on_policy_rule as okta_sign_on_policy_rule
OktaSignOnPolicyRule = okta_sign_on_policy_rule.OktaSignOnPolicyRule
import okta.models.okta_sign_on_policy_rule_actions as okta_sign_on_policy_rule_actions
OktaSignOnPolicyRuleActions = okta_sign_on_policy_rule_actions.OktaSignOnPolicyRuleActions
import okta.models.okta_sign_on_policy_rule_conditions as okta_sign_on_policy_rule_conditions
OktaSignOnPolicyRuleConditions = okta_sign_on_policy_rule_conditions.OktaSignOnPolicyRuleConditions
import okta.models.okta_sign_on_policy_rule_signon_actions as okta_sign_on_policy_rule_signon_actions
OktaSignOnPolicyRuleSignonActions = okta_sign_on_policy_rule_signon_actions.OktaSignOnPolicyRuleSignonActions
import okta.models.okta_sign_on_policy_rule_signon_session_actions as okta_sign_on_policy_rule_signon_session_actions
OktaSignOnPolicyRuleSignonSessionActions = okta_sign_on_policy_rule_signon_session_actions.OktaSignOnPolicyRuleSignonSessionActions
import okta.models.open_id_connect_application as open_id_connect_application
OpenIdConnectApplication = open_id_connect_application.OpenIdConnectApplication
import okta.models.open_id_connect_application_consent_method as open_id_connect_application_consent_method
OpenIdConnectApplicationConsentMethod = open_id_connect_application_consent_method.OpenIdConnectApplicationConsentMethod
import okta.models.open_id_connect_application_issuer_mode as open_id_connect_application_issuer_mode
OpenIdConnectApplicationIssuerMode = open_id_connect_application_issuer_mode.OpenIdConnectApplicationIssuerMode
import okta.models.open_id_connect_application_settings as open_id_connect_application_settings
OpenIdConnectApplicationSettings = open_id_connect_application_settings.OpenIdConnectApplicationSettings
import okta.models.open_id_connect_application_settings_client as open_id_connect_application_settings_client
OpenIdConnectApplicationSettingsClient = open_id_connect_application_settings_client.OpenIdConnectApplicationSettingsClient
import okta.models.open_id_connect_application_type as open_id_connect_application_type
OpenIdConnectApplicationType = open_id_connect_application_type.OpenIdConnectApplicationType
import okta.models.password_credential as password_credential
PasswordCredential = password_credential.PasswordCredential
import okta.models.password_credential_hash as password_credential_hash
PasswordCredentialHash = password_credential_hash.PasswordCredentialHash
import okta.models.password_credential_hash_algorithm as password_credential_hash_algorithm
PasswordCredentialHashAlgorithm = password_credential_hash_algorithm.PasswordCredentialHashAlgorithm
import okta.models.password_credential_hook as password_credential_hook
PasswordCredentialHook = password_credential_hook.PasswordCredentialHook
import okta.models.password_dictionary as password_dictionary
PasswordDictionary = password_dictionary.PasswordDictionary
import okta.models.password_dictionary_common as password_dictionary_common
PasswordDictionaryCommon = password_dictionary_common.PasswordDictionaryCommon
import okta.models.password_expiration_policy_rule_condition as password_expiration_policy_rule_condition
PasswordExpirationPolicyRuleCondition = password_expiration_policy_rule_condition.PasswordExpirationPolicyRuleCondition
import okta.models.password_policy as password_policy
PasswordPolicy = password_policy.PasswordPolicy
import okta.models.password_policy_authentication_provider_condition as password_policy_authentication_provider_condition
PasswordPolicyAuthenticationProviderCondition = password_policy_authentication_provider_condition.PasswordPolicyAuthenticationProviderCondition
import okta.models.password_policy_conditions as password_policy_conditions
PasswordPolicyConditions = password_policy_conditions.PasswordPolicyConditions
import okta.models.password_policy_delegation_settings as password_policy_delegation_settings
PasswordPolicyDelegationSettings = password_policy_delegation_settings.PasswordPolicyDelegationSettings
import okta.models.password_policy_delegation_settings_options as password_policy_delegation_settings_options
PasswordPolicyDelegationSettingsOptions = password_policy_delegation_settings_options.PasswordPolicyDelegationSettingsOptions
import okta.models.password_policy_password_settings as password_policy_password_settings
PasswordPolicyPasswordSettings = password_policy_password_settings.PasswordPolicyPasswordSettings
import okta.models.password_policy_password_settings_age as password_policy_password_settings_age
PasswordPolicyPasswordSettingsAge = password_policy_password_settings_age.PasswordPolicyPasswordSettingsAge
import okta.models.password_policy_password_settings_complexity as password_policy_password_settings_complexity
PasswordPolicyPasswordSettingsComplexity = password_policy_password_settings_complexity.PasswordPolicyPasswordSettingsComplexity
import okta.models.password_policy_password_settings_lockout as password_policy_password_settings_lockout
PasswordPolicyPasswordSettingsLockout = password_policy_password_settings_lockout.PasswordPolicyPasswordSettingsLockout
import okta.models.password_policy_recovery_email as password_policy_recovery_email
PasswordPolicyRecoveryEmail = password_policy_recovery_email.PasswordPolicyRecoveryEmail
import okta.models.password_policy_recovery_email_properties as password_policy_recovery_email_properties
PasswordPolicyRecoveryEmailProperties = password_policy_recovery_email_properties.PasswordPolicyRecoveryEmailProperties
import okta.models.password_policy_recovery_email_recovery_token as password_policy_recovery_email_recovery_token
PasswordPolicyRecoveryEmailRecoveryToken = password_policy_recovery_email_recovery_token.PasswordPolicyRecoveryEmailRecoveryToken
import okta.models.password_policy_recovery_factor_settings as password_policy_recovery_factor_settings
PasswordPolicyRecoveryFactorSettings = password_policy_recovery_factor_settings.PasswordPolicyRecoveryFactorSettings
import okta.models.password_policy_recovery_factors as password_policy_recovery_factors
PasswordPolicyRecoveryFactors = password_policy_recovery_factors.PasswordPolicyRecoveryFactors
import okta.models.password_policy_recovery_question as password_policy_recovery_question
PasswordPolicyRecoveryQuestion = password_policy_recovery_question.PasswordPolicyRecoveryQuestion
import okta.models.password_policy_recovery_question_complexity as password_policy_recovery_question_complexity
PasswordPolicyRecoveryQuestionComplexity = password_policy_recovery_question_complexity.PasswordPolicyRecoveryQuestionComplexity
import okta.models.password_policy_recovery_question_properties as password_policy_recovery_question_properties
PasswordPolicyRecoveryQuestionProperties = password_policy_recovery_question_properties.PasswordPolicyRecoveryQuestionProperties
import okta.models.password_policy_recovery_settings as password_policy_recovery_settings
PasswordPolicyRecoverySettings = password_policy_recovery_settings.PasswordPolicyRecoverySettings
import okta.models.password_policy_rule as password_policy_rule
PasswordPolicyRule = password_policy_rule.PasswordPolicyRule
import okta.models.password_policy_rule_action as password_policy_rule_action
PasswordPolicyRuleAction = password_policy_rule_action.PasswordPolicyRuleAction
import okta.models.password_policy_rule_actions as password_policy_rule_actions
PasswordPolicyRuleActions = password_policy_rule_actions.PasswordPolicyRuleActions
import okta.models.password_policy_rule_conditions as password_policy_rule_conditions
PasswordPolicyRuleConditions = password_policy_rule_conditions.PasswordPolicyRuleConditions
import okta.models.password_policy_settings as password_policy_settings
PasswordPolicySettings = password_policy_settings.PasswordPolicySettings
import okta.models.platform_condition_evaluator_platform as platform_condition_evaluator_platform
PlatformConditionEvaluatorPlatform = platform_condition_evaluator_platform.PlatformConditionEvaluatorPlatform
import okta.models.platform_condition_evaluator_platform_operating_system as platform_condition_evaluator_platform_operating_system
PlatformConditionEvaluatorPlatformOperatingSystem = platform_condition_evaluator_platform_operating_system.PlatformConditionEvaluatorPlatformOperatingSystem
import okta.models.platform_condition_evaluator_platform_operating_system_version as platform_condition_evaluator_platform_operating_system_version
PlatformConditionEvaluatorPlatformOperatingSystemVersion = platform_condition_evaluator_platform_operating_system_version.PlatformConditionEvaluatorPlatformOperatingSystemVersion
import okta.models.platform_policy_rule_condition as platform_policy_rule_condition
PlatformPolicyRuleCondition = platform_policy_rule_condition.PlatformPolicyRuleCondition
import okta.models.policy as policy
Policy = policy.Policy
import okta.models.policy_account_link as policy_account_link
PolicyAccountLink = policy_account_link.PolicyAccountLink
import okta.models.policy_account_link_filter as policy_account_link_filter
PolicyAccountLinkFilter = policy_account_link_filter.PolicyAccountLinkFilter
import okta.models.policy_account_link_filter_groups as policy_account_link_filter_groups
PolicyAccountLinkFilterGroups = policy_account_link_filter_groups.PolicyAccountLinkFilterGroups
import okta.models.policy_network_condition as policy_network_condition
PolicyNetworkCondition = policy_network_condition.PolicyNetworkCondition
import okta.models.policy_people_condition as policy_people_condition
PolicyPeopleCondition = policy_people_condition.PolicyPeopleCondition
import okta.models.policy_rule as policy_rule
PolicyRule = policy_rule.PolicyRule
import okta.models.policy_rule_auth_context_condition as policy_rule_auth_context_condition
PolicyRuleAuthContextCondition = policy_rule_auth_context_condition.PolicyRuleAuthContextCondition
import okta.models.policy_rule_conditions as policy_rule_conditions
PolicyRuleConditions = policy_rule_conditions.PolicyRuleConditions
import okta.models.policy_subject as policy_subject
PolicySubject = policy_subject.PolicySubject
import okta.models.policy_subject_match_type as policy_subject_match_type
PolicySubjectMatchType = policy_subject_match_type.PolicySubjectMatchType
import okta.models.policy_type as policy_type
PolicyType = policy_type.PolicyType
import okta.models.policy_user_name_template as policy_user_name_template
PolicyUserNameTemplate = policy_user_name_template.PolicyUserNameTemplate
import okta.models.protocol as protocol
Protocol = protocol.Protocol
import okta.models.protocol_algorithm_type as protocol_algorithm_type
ProtocolAlgorithmType = protocol_algorithm_type.ProtocolAlgorithmType
import okta.models.protocol_algorithm_type_signature as protocol_algorithm_type_signature
ProtocolAlgorithmTypeSignature = protocol_algorithm_type_signature.ProtocolAlgorithmTypeSignature
import okta.models.protocol_algorithms as protocol_algorithms
ProtocolAlgorithms = protocol_algorithms.ProtocolAlgorithms
import okta.models.protocol_endpoint as protocol_endpoint
ProtocolEndpoint = protocol_endpoint.ProtocolEndpoint
import okta.models.protocol_endpoints as protocol_endpoints
ProtocolEndpoints = protocol_endpoints.ProtocolEndpoints
import okta.models.protocol_relay_state as protocol_relay_state
ProtocolRelayState = protocol_relay_state.ProtocolRelayState
import okta.models.protocol_relay_state_format as protocol_relay_state_format
ProtocolRelayStateFormat = protocol_relay_state_format.ProtocolRelayStateFormat
import okta.models.protocol_settings as protocol_settings
ProtocolSettings = protocol_settings.ProtocolSettings
import okta.models.provisioning as provisioning
Provisioning = provisioning.Provisioning
import okta.models.provisioning_conditions as provisioning_conditions
ProvisioningConditions = provisioning_conditions.ProvisioningConditions
import okta.models.provisioning_deprovisioned_condition as provisioning_deprovisioned_condition
ProvisioningDeprovisionedCondition = provisioning_deprovisioned_condition.ProvisioningDeprovisionedCondition
import okta.models.provisioning_groups as provisioning_groups
ProvisioningGroups = provisioning_groups.ProvisioningGroups
import okta.models.provisioning_suspended_condition as provisioning_suspended_condition
ProvisioningSuspendedCondition = provisioning_suspended_condition.ProvisioningSuspendedCondition
import okta.models.push_user_factor as push_user_factor
PushUserFactor = push_user_factor.PushUserFactor
import okta.models.push_user_factor_profile as push_user_factor_profile
PushUserFactorProfile = push_user_factor_profile.PushUserFactorProfile
import okta.models.recovery_question_credential as recovery_question_credential
RecoveryQuestionCredential = recovery_question_credential.RecoveryQuestionCredential
import okta.models.reset_password_token as reset_password_token
ResetPasswordToken = reset_password_token.ResetPasswordToken
import okta.models.response_links as response_links
ResponseLinks = response_links.ResponseLinks
import okta.models.risk_policy_rule_condition as risk_policy_rule_condition
RiskPolicyRuleCondition = risk_policy_rule_condition.RiskPolicyRuleCondition
import okta.models.risk_score_policy_rule_condition as risk_score_policy_rule_condition
RiskScorePolicyRuleCondition = risk_score_policy_rule_condition.RiskScorePolicyRuleCondition
import okta.models.role as role
Role = role.Role
import okta.models.role_assignment_type as role_assignment_type
RoleAssignmentType = role_assignment_type.RoleAssignmentType
import okta.models.role_status as role_status
RoleStatus = role_status.RoleStatus
import okta.models.role_type as role_type
RoleType = role_type.RoleType
import okta.models.saml_application as saml_application
SamlApplication = saml_application.SamlApplication
import okta.models.saml_application_settings as saml_application_settings
SamlApplicationSettings = saml_application_settings.SamlApplicationSettings
import okta.models.saml_application_settings_sign_on as saml_application_settings_sign_on
SamlApplicationSettingsSignOn = saml_application_settings_sign_on.SamlApplicationSettingsSignOn
import okta.models.saml_attribute_statement as saml_attribute_statement
SamlAttributeStatement = saml_attribute_statement.SamlAttributeStatement
import okta.models.scheduled_user_lifecycle_action as scheduled_user_lifecycle_action
ScheduledUserLifecycleAction = scheduled_user_lifecycle_action.ScheduledUserLifecycleAction
import okta.models.scheme_application_credentials as scheme_application_credentials
SchemeApplicationCredentials = scheme_application_credentials.SchemeApplicationCredentials
import okta.models.scope as scope
Scope = scope.Scope
import okta.models.scope_type as scope_type
ScopeType = scope_type.ScopeType
import okta.models.secure_password_store_application as secure_password_store_application
SecurePasswordStoreApplication = secure_password_store_application.SecurePasswordStoreApplication
import okta.models.secure_password_store_application_settings as secure_password_store_application_settings
SecurePasswordStoreApplicationSettings = secure_password_store_application_settings.SecurePasswordStoreApplicationSettings
import okta.models.secure_password_store_application_settings_application as secure_password_store_application_settings_application
SecurePasswordStoreApplicationSettingsApplication = secure_password_store_application_settings_application.SecurePasswordStoreApplicationSettingsApplication
import okta.models.security_question as security_question
SecurityQuestion = security_question.SecurityQuestion
import okta.models.security_question_user_factor as security_question_user_factor
SecurityQuestionUserFactor = security_question_user_factor.SecurityQuestionUserFactor
import okta.models.security_question_user_factor_profile as security_question_user_factor_profile
SecurityQuestionUserFactorProfile = security_question_user_factor_profile.SecurityQuestionUserFactorProfile
import okta.models.session as session
Session = session.Session
import okta.models.session_authentication_method as session_authentication_method
SessionAuthenticationMethod = session_authentication_method.SessionAuthenticationMethod
import okta.models.session_identity_provider as session_identity_provider
SessionIdentityProvider = session_identity_provider.SessionIdentityProvider
import okta.models.session_identity_provider_type as session_identity_provider_type
SessionIdentityProviderType = session_identity_provider_type.SessionIdentityProviderType
import okta.models.session_status as session_status
SessionStatus = session_status.SessionStatus
import okta.models.sms_template as sms_template
SmsTemplate = sms_template.SmsTemplate
import okta.models.sms_template_translations as sms_template_translations
SmsTemplateTranslations = sms_template_translations.SmsTemplateTranslations
import okta.models.sms_template_type as sms_template_type
SmsTemplateType = sms_template_type.SmsTemplateType
import okta.models.sms_user_factor as sms_user_factor
SmsUserFactor = sms_user_factor.SmsUserFactor
import okta.models.sms_user_factor_profile as sms_user_factor_profile
SmsUserFactorProfile = sms_user_factor_profile.SmsUserFactorProfile
import okta.models.social_auth_token as social_auth_token
SocialAuthToken = social_auth_token.SocialAuthToken
import okta.models.swa_application as swa_application
SwaApplication = swa_application.SwaApplication
import okta.models.swa_application_settings as swa_application_settings
SwaApplicationSettings = swa_application_settings.SwaApplicationSettings
import okta.models.swa_application_settings_application as swa_application_settings_application
SwaApplicationSettingsApplication = swa_application_settings_application.SwaApplicationSettingsApplication
import okta.models.swa_three_field_application as swa_three_field_application
SwaThreeFieldApplication = swa_three_field_application.SwaThreeFieldApplication
import okta.models.swa_three_field_application_settings as swa_three_field_application_settings
SwaThreeFieldApplicationSettings = swa_three_field_application_settings.SwaThreeFieldApplicationSettings
import okta.models.swa_three_field_application_settings_application as swa_three_field_application_settings_application
SwaThreeFieldApplicationSettingsApplication = swa_three_field_application_settings_application.SwaThreeFieldApplicationSettingsApplication
import okta.models.temp_password as temp_password
TempPassword = temp_password.TempPassword
import okta.models.token_user_factor as token_user_factor
TokenUserFactor = token_user_factor.TokenUserFactor
import okta.models.token_user_factor_profile as token_user_factor_profile
TokenUserFactorProfile = token_user_factor_profile.TokenUserFactorProfile
import okta.models.totp_user_factor as totp_user_factor
TotpUserFactor = totp_user_factor.TotpUserFactor
import okta.models.totp_user_factor_profile as totp_user_factor_profile
TotpUserFactorProfile = totp_user_factor_profile.TotpUserFactorProfile
import okta.models.trusted_origin as trusted_origin
TrustedOrigin = trusted_origin.TrustedOrigin
import okta.models.u_2_f_user_factor as u_2_f_user_factor
U2FUserFactor = u_2_f_user_factor.U2FUserFactor
import okta.models.u_2_f_user_factor_profile as u_2_f_user_factor_profile
U2FUserFactorProfile = u_2_f_user_factor_profile.U2FUserFactorProfile
import okta.models.user as user
User = user.User
import okta.models.user_activation_token as user_activation_token
UserActivationToken = user_activation_token.UserActivationToken
import okta.models.user_condition as user_condition
UserCondition = user_condition.UserCondition
import okta.models.user_credentials as user_credentials
UserCredentials = user_credentials.UserCredentials
import okta.models.user_factor as user_factor
UserFactor = user_factor.UserFactor
import okta.models.user_identifier_condition_evaluator_pattern as user_identifier_condition_evaluator_pattern
UserIdentifierConditionEvaluatorPattern = user_identifier_condition_evaluator_pattern.UserIdentifierConditionEvaluatorPattern
import okta.models.user_identifier_policy_rule_condition as user_identifier_policy_rule_condition
UserIdentifierPolicyRuleCondition = user_identifier_policy_rule_condition.UserIdentifierPolicyRuleCondition
import okta.models.user_identity_provider_link_request as user_identity_provider_link_request
UserIdentityProviderLinkRequest = user_identity_provider_link_request.UserIdentityProviderLinkRequest
import okta.models.user_lifecycle_attribute_policy_rule_condition as user_lifecycle_attribute_policy_rule_condition
UserLifecycleAttributePolicyRuleCondition = user_lifecycle_attribute_policy_rule_condition.UserLifecycleAttributePolicyRuleCondition
import okta.models.user_next_login as user_next_login
UserNextLogin = user_next_login.UserNextLogin
import okta.models.user_policy_rule_condition as user_policy_rule_condition
UserPolicyRuleCondition = user_policy_rule_condition.UserPolicyRuleCondition
import okta.models.user_profile as user_profile
UserProfile = user_profile.UserProfile
import okta.models.user_status as user_status
UserStatus = user_status.UserStatus
import okta.models.user_status_policy_rule_condition as user_status_policy_rule_condition
UserStatusPolicyRuleCondition = user_status_policy_rule_condition.UserStatusPolicyRuleCondition
import okta.models.user_type as user_type
UserType = user_type.UserType
import okta.models.verify_factor_request as verify_factor_request
VerifyFactorRequest = verify_factor_request.VerifyFactorRequest
import okta.models.verify_user_factor_response as verify_user_factor_response
VerifyUserFactorResponse = verify_user_factor_response.VerifyUserFactorResponse
import okta.models.web_authn_user_factor as web_authn_user_factor
WebAuthnUserFactor = web_authn_user_factor.WebAuthnUserFactor
import okta.models.web_authn_user_factor_profile as web_authn_user_factor_profile
WebAuthnUserFactorProfile = web_authn_user_factor_profile.WebAuthnUserFactorProfile
import okta.models.web_user_factor as web_user_factor
WebUserFactor = web_user_factor.WebUserFactor
import okta.models.web_user_factor_profile as web_user_factor_profile
WebUserFactorProfile = web_user_factor_profile.WebUserFactorProfile
import okta.models.ws_federation_application as ws_federation_application
WsFederationApplication = ws_federation_application.WsFederationApplication
import okta.models.ws_federation_application_settings as ws_federation_application_settings
WsFederationApplicationSettings = ws_federation_application_settings.WsFederationApplicationSettings
import okta.models.ws_federation_application_settings_application as ws_federation_application_settings_application
WsFederationApplicationSettingsApplication = ws_federation_application_settings_application.WsFederationApplicationSettingsApplication



# flake8: noqa
"""
Copyright 2020 - Present Okta, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

# AUTO-GENERATED! DO NOT EDIT FILE DIRECTLY
# SEE CONTRIBUTOR DOCUMENTATION

from okta.okta_object import OktaObject
import okta.models.app_and_instance_policy_rule_condition\
    as app_and_instance_policy_rule_condition
import okta.models.app_instance_policy_rule_condition\
    as app_instance_policy_rule_condition
import okta.models.policy_rule_auth_context_condition\
    as policy_rule_auth_context_condition
import okta.models.password_policy_authentication_provider_condition\
    as password_policy_authentication_provider_condition
import okta.models.before_scheduled_action_policy_rule_condition\
    as before_scheduled_action_policy_rule_condition
import okta.models.client_policy_condition\
    as client_policy_condition
import okta.models.context_policy_rule_condition\
    as context_policy_rule_condition
import okta.models.device_policy_rule_condition\
    as device_policy_rule_condition
import okta.models.grant_type_policy_rule_condition\
    as grant_type_policy_rule_condition
import okta.models.group_policy_rule_condition\
    as group_policy_rule_condition
import okta.models.identity_provider_policy_rule_condition\
    as identity_provider_policy_rule_condition
import okta.models.mdm_enrollment_policy_rule_condition\
    as mdm_enrollment_policy_rule_condition
import okta.models.policy_network_condition\
    as policy_network_condition
import okta.models.policy_people_condition\
    as policy_people_condition
import okta.models.platform_policy_rule_condition\
    as platform_policy_rule_condition
import okta.models.risk_policy_rule_condition\
    as risk_policy_rule_condition
import okta.models.risk_score_policy_rule_condition\
    as risk_score_policy_rule_condition
import okta.models.o_auth_2_scopes_mediation_policy_rule_condition\
    as o_auth_2_scopes_mediation_policy_rule_condition
import okta.models.user_identifier_policy_rule_condition\
    as user_identifier_policy_rule_condition
import okta.models.user_status_policy_rule_condition\
    as user_status_policy_rule_condition
import okta.models.user_policy_rule_condition\
    as user_policy_rule_condition


class PolicyRuleConditions(
    OktaObject
):
    """
    A class for PolicyRuleConditions objects.
    """

    def __init__(self, config=None):
        super().__init__(config)
        if config:
            if "app" in config:
                if isinstance(config["app"],
                              app_and_instance_policy_rule_condition.AppAndInstancePolicyRuleCondition):
                    self.app = config["app"]
                else:
                    self.app = app_and_instance_policy_rule_condition.AppAndInstancePolicyRuleCondition(
                        config["app"]
                    )
            else:
                self.app = None
            if "apps" in config:
                if isinstance(config["apps"],
                              app_instance_policy_rule_condition.AppInstancePolicyRuleCondition):
                    self.apps = config["apps"]
                else:
                    self.apps = app_instance_policy_rule_condition.AppInstancePolicyRuleCondition(
                        config["apps"]
                    )
            else:
                self.apps = None
            if "authContext" in config:
                if isinstance(config["authContext"],
                              policy_rule_auth_context_condition.PolicyRuleAuthContextCondition):
                    self.auth_context = config["authContext"]
                else:
                    self.auth_context = policy_rule_auth_context_condition.PolicyRuleAuthContextCondition(
                        config["authContext"]
                    )
            else:
                self.auth_context = None
            if "authProvider" in config:
                if isinstance(config["authProvider"],
                              password_policy_authentication_provider_condition.PasswordPolicyAuthenticationProviderCondition):
                    self.auth_provider = config["authProvider"]
                else:
                    self.auth_provider = password_policy_authentication_provider_condition.PasswordPolicyAuthenticationProviderCondition(
                        config["authProvider"]
                    )
            else:
                self.auth_provider = None
            if "beforeScheduledAction" in config:
                if isinstance(config["beforeScheduledAction"],
                              before_scheduled_action_policy_rule_condition.BeforeScheduledActionPolicyRuleCondition):
                    self.before_scheduled_action = config["beforeScheduledAction"]
                else:
                    self.before_scheduled_action = before_scheduled_action_policy_rule_condition.BeforeScheduledActionPolicyRuleCondition(
                        config["beforeScheduledAction"]
                    )
            else:
                self.before_scheduled_action = None
            if "clients" in config:
                if isinstance(config["clients"],
                              client_policy_condition.ClientPolicyCondition):
                    self.clients = config["clients"]
                else:
                    self.clients = client_policy_condition.ClientPolicyCondition(
                        config["clients"]
                    )
            else:
                self.clients = None
            if "context" in config:
                if isinstance(config["context"],
                              context_policy_rule_condition.ContextPolicyRuleCondition):
                    self.context = config["context"]
                else:
                    self.context = context_policy_rule_condition.ContextPolicyRuleCondition(
                        config["context"]
                    )
            else:
                self.context = None
            if "device" in config:
                if isinstance(config["device"],
                              device_policy_rule_condition.DevicePolicyRuleCondition):
                    self.device = config["device"]
                else:
                    self.device = device_policy_rule_condition.DevicePolicyRuleCondition(
                        config["device"]
                    )
            else:
                self.device = None
            if "grantTypes" in config:
                if isinstance(config["grantTypes"],
                              grant_type_policy_rule_condition.GrantTypePolicyRuleCondition):
                    self.grant_types = config["grantTypes"]
                else:
                    self.grant_types = grant_type_policy_rule_condition.GrantTypePolicyRuleCondition(
                        config["grantTypes"]
                    )
            else:
                self.grant_types = None
            if "groups" in config:
                if isinstance(config["groups"],
                              group_policy_rule_condition.GroupPolicyRuleCondition):
                    self.groups = config["groups"]
                else:
                    self.groups = group_policy_rule_condition.GroupPolicyRuleCondition(
                        config["groups"]
                    )
            else:
                self.groups = None
            if "identityProvider" in config:
                if isinstance(config["identityProvider"],
                              identity_provider_policy_rule_condition.IdentityProviderPolicyRuleCondition):
                    self.identity_provider = config["identityProvider"]
                else:
                    self.identity_provider = identity_provider_policy_rule_condition.IdentityProviderPolicyRuleCondition(
                        config["identityProvider"]
                    )
            else:
                self.identity_provider = None
            if "mdmEnrollment" in config:
                if isinstance(config["mdmEnrollment"],
                              mdm_enrollment_policy_rule_condition.MdmEnrollmentPolicyRuleCondition):
                    self.mdm_enrollment = config["mdmEnrollment"]
                else:
                    self.mdm_enrollment = mdm_enrollment_policy_rule_condition.MdmEnrollmentPolicyRuleCondition(
                        config["mdmEnrollment"]
                    )
            else:
                self.mdm_enrollment = None
            if "network" in config:
                if isinstance(config["network"],
                              policy_network_condition.PolicyNetworkCondition):
                    self.network = config["network"]
                else:
                    self.network = policy_network_condition.PolicyNetworkCondition(
                        config["network"]
                    )
            else:
                self.network = None
            if "people" in config:
                if isinstance(config["people"],
                              policy_people_condition.PolicyPeopleCondition):
                    self.people = config["people"]
                else:
                    self.people = policy_people_condition.PolicyPeopleCondition(
                        config["people"]
                    )
            else:
                self.people = None
            if "platform" in config:
                if isinstance(config["platform"],
                              platform_policy_rule_condition.PlatformPolicyRuleCondition):
                    self.platform = config["platform"]
                else:
                    self.platform = platform_policy_rule_condition.PlatformPolicyRuleCondition(
                        config["platform"]
                    )
            else:
                self.platform = None
            if "risk" in config:
                if isinstance(config["risk"],
                              risk_policy_rule_condition.RiskPolicyRuleCondition):
                    self.risk = config["risk"]
                else:
                    self.risk = risk_policy_rule_condition.RiskPolicyRuleCondition(
                        config["risk"]
                    )
            else:
                self.risk = None
            if "riskScore" in config:
                if isinstance(config["riskScore"],
                              risk_score_policy_rule_condition.RiskScorePolicyRuleCondition):
                    self.risk_score = config["riskScore"]
                else:
                    self.risk_score = risk_score_policy_rule_condition.RiskScorePolicyRuleCondition(
                        config["riskScore"]
                    )
            else:
                self.risk_score = None
            if "scopes" in config:
                if isinstance(config["scopes"],
                              o_auth_2_scopes_mediation_policy_rule_condition.OAuth2ScopesMediationPolicyRuleCondition):
                    self.scopes = config["scopes"]
                else:
                    self.scopes = o_auth_2_scopes_mediation_policy_rule_condition.OAuth2ScopesMediationPolicyRuleCondition(
                        config["scopes"]
                    )
            else:
                self.scopes = None
            if "userIdentifier" in config:
                if isinstance(config["userIdentifier"],
                              user_identifier_policy_rule_condition.UserIdentifierPolicyRuleCondition):
                    self.user_identifier = config["userIdentifier"]
                else:
                    self.user_identifier = user_identifier_policy_rule_condition.UserIdentifierPolicyRuleCondition(
                        config["userIdentifier"]
                    )
            else:
                self.user_identifier = None
            if "userStatus" in config:
                if isinstance(config["userStatus"],
                              user_status_policy_rule_condition.UserStatusPolicyRuleCondition):
                    self.user_status = config["userStatus"]
                else:
                    self.user_status = user_status_policy_rule_condition.UserStatusPolicyRuleCondition(
                        config["userStatus"]
                    )
            else:
                self.user_status = None
            if "users" in config:
                if isinstance(config["users"],
                              user_policy_rule_condition.UserPolicyRuleCondition):
                    self.users = config["users"]
                else:
                    self.users = user_policy_rule_condition.UserPolicyRuleCondition(
                        config["users"]
                    )
            else:
                self.users = None
        else:
            self.app = None
            self.apps = None
            self.auth_context = None
            self.auth_provider = None
            self.before_scheduled_action = None
            self.clients = None
            self.context = None
            self.device = None
            self.grant_types = None
            self.groups = None
            self.identity_provider = None
            self.mdm_enrollment = None
            self.network = None
            self.people = None
            self.platform = None
            self.risk = None
            self.risk_score = None
            self.scopes = None
            self.user_identifier = None
            self.user_status = None
            self.users = None

    def request_format(self):
        parent_req_format = super().request_format()
        current_obj_format = {
            "app": self.app,
            "apps": self.apps,
            "authContext": self.auth_context,
            "authProvider": self.auth_provider,
            "beforeScheduledAction": self.before_scheduled_action,
            "clients": self.clients,
            "context": self.context,
            "device": self.device,
            "grantTypes": self.grant_types,
            "groups": self.groups,
            "identityProvider": self.identity_provider,
            "mdmEnrollment": self.mdm_enrollment,
            "network": self.network,
            "people": self.people,
            "platform": self.platform,
            "risk": self.risk,
            "riskScore": self.risk_score,
            "scopes": self.scopes,
            "userIdentifier": self.user_identifier,
            "userStatus": self.user_status,
            "users": self.users
        }
        parent_req_format.update(current_obj_format)
        return parent_req_format
